//--------------------------------------------------------------------------
//
// Copyright 2013, Cypress Semiconductor Corporation.
//
// This software is owned by Cypress Semiconductor Corporation (Cypress)
// and is protected by and subject to worldwide patent protection (United
// States and foreign), United States copyright laws and international
// treaty provisions. Cypress hereby grants to licensee a personal,
// non-exclusive, non-transferable license to copy, use, modify, create
// derivative works of, and compile the Cypress Source Code and derivative
// works for the sole purpose of creating custom software in support of
// licensee product to be used only in conjunction with a Cypress integrated
// circuit as specified in the applicable agreement. Any reproduction,
// modification, translation, compilation, or representation of this
// software except as specified above is prohibited without the express
// written permission of Cypress.
//
// Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND,EXPRESS OR IMPLIED,
// WITH REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// Cypress reserves the right to make changes without further notice to the
// materials described herein. Cypress does not assume any liability arising
// out of the application or use of any product or circuit described herein.
// Cypress does not authorize its products for use as critical components in
// life-support systems where a malfunction or failure may reasonably be
// expected to result in significant injury to the user. The inclusion of
// Cypress' product in a life-support systems application implies that the
// manufacturer assumes all risk of such use and in doing so indemnifies
// Cypress against all charges.
//
// Use may be limited by and subject to the applicable Cypress software
// license agreement.
//
//--------------------------------------------------------------------------
/****************************************************************************
 ****************************************************************************
  FILENAME: main.c
   Version: 1.1, Updated on 09 April 2013

  DESCRIPTION: Main file of the Example_SineWave_DAC Project.
-----------------------------------------------------------------------------
  Copyright (c) Cypress MicroSystems 2009-2013. All Rights Reserved.
*****************************************************************************
*****************************************************************************
*****************************************************************************
 
The Kits CY3210-PSoCEVAL1 Board OR CY3210-MiniEval1 Board can be used for testing the Project.

Project Objective:-
    To generate a Sine Wave with an 8-Bit DAC, 16-bit Counter and Lookup Table.
    
Overview:-
    This project demonstrates a simple and easy way to generate a Sine Wave in PSoC using a 64 point lookup table, 
	a DAC and a time base.  The sample project generates a 60Hz sine wave.  
	The output frequency can be varied by changing the time base and the number of samples per cycle.  

    The following changes were made to the default settings in the Device Editor:
 
    A)-Select User Modules
         1. Select an DAC8 from the DACs User Modules category.
         2. In this example, these UM is named DAC8_1
		 3. Select an Counter16 from the Counters User Modules category.
         4. In this example, these UM is named Counter16_1
		 
    B)-Place User Modules
         1. Select DAC8_1 and place it on block ASC10 and ASD20.
		 2. Select Counter16_1 and place it on block DBB00 and DBB01.

    Set the Global Resources and UM parameters in the Device Editor as shown under 
    "Project Settings" ahead.
	
--------------------------------------------------------------------------------------------------------
Project Settings:-

    Global Resources: 
        CPU_Clock      = 24MHz(SysClk/1)      ;CPU clock set to 24 MHz
        VC1            = SysClk/12	          ;Set VC1 output as 2MHz. 
        SysClk Source  = Internal 24_MHz      ;Selects 24MHz System Clock
		Analog Power   = SC ON/Ref High       ;Controls the power to the analog section.
		Ref Mux        = (Vdd/2)+/-(Vdd/2)    ;AGND = 2.5V Range= 0V to 5V.
		Supply Voltage = 5.0V                 ;Selects 5V operation 
		
    User Module Parameters:

		Counter16_1:    		
        Clock		   	= VC1                  ;NA.  This parameter will be over-ridden by the ClockSync parameter
		Enable		   	= High                 ;Enable the counter
		Period	        = 6249                 ;A period of 6249 results in a divider of 6250.  
                                               ;The output frequency from the counter is 24MHz / 6250 = 3.84KHz
        CompareValue	= 3125                 ;Set Duty Cycle to 50% 
        CompareType	    = Less Than Or Equal   ;
		InterruptType   = Terminal Count       ;Generates an interrupt on terminal count.
		ClockSync       = Use SysClk Direct    ;24Mhz Clock is fed to Counter UM.This setting over-rides the Clock parameter

		DAC8_1:
		AnalogBus		= AnalogOutBus_0       ;Connect the DAC output to P0[3] via analog output buffers
		ClockPhase	    = Normal               ;Auto-zero cycle occurs during phase-1 and output of DAC is valid in phase-2
		DataFormat	    = OffsetBinary         ;Offset-binary values are positive numbers, with the lowest output voltage represented by zero and the highest by 254.

        Note : 1. For further information on the above parameters refer to the User Module Datasheet

	
	Operation:
	    The sample rate required to produce the desired output frequency is given by formula
			Sample Rate = Output Frequency × No.Of Samples
		
		The formula to create the samples of the lookup table is
			Value_n =(Sin[n×(360/64)]×Full Scale)+ Zero

		where
			n = Sample Number (0 to 63)
			Full Scale = +/- Full Scale count for the DAC, which is 127 for DAC8
			Zero = Value at which DAC produces 0V, which is 127 for DAC8
	  
    Hardware Connections:-
        This project does not require any external components.  When the PSoC device is programmed and powered, 
		the output signal may be observed on P0[3] using an oscilloscope.
        
	Programming Language Used: C
    Compiler: Imagecraft      
	
	Note: The output frequency can be varied
    1. By changing the output frequency of Counter.
    2. By changing the number of samples per cycle.  For the same 64 point look up table, if the
       Pointer is incremented by 2, the number of samples becomes 32.
*/

//----------------------------------------------------------------------------
// C main line
/**Programmer Setup- Cypress Mini Programmer */
/*Acquire Mode : RESET */
/*Verification : ON */
/*Power Setting : 3.3*/
//----------------------------------------------------------------------------

#include <m8c.h>        // part specific constants and macros
#include "PSoCAPI.h"    // PSoC API definitions for all User Modules

void ControlVoltage(unsigned int comm);
void delay(unsigned long wait);

void main(void)
{

    unsigned int  Value =0;
	
    M8C_EnableGInt;      
    M8C_ClearIntFlag(INT_CLR0, 0);
    DAC9_1_Start(2);
    VLT_CR = VLT_CR_POR_HIGH;
	while(1)
	{ 
        if(((PRT2DR & 0x01) == 1) && ((PRT2DR & 0x07) != 7))
			ControlVoltage(1350+Value),Value+=3;	//1350
		
		if((PRT2DR & 0x07) == 7)
			ControlVoltage(1780);	// For 2.5V 
		
		if(!(PRT2DR))
			ControlVoltage(0),Value=0;		
    }


void delay(unsigned long wait)
{
	while(wait--);
}

void ControlVoltage(unsigned int comm)
{
float f =0.0;
unsigned int Data;
	f  = comm ;
	f = f /3280.0;
	f = f * 512.00;	
	Data = (unsigned int) f;
	DAC9_1_WriteBlind(Data);	
}
